package org.apache.bcel.util;

import java.util.HashMap;
import org.apache.bcel.classfile.JavaClass;
import java.lang.ref.SoftReference;
import java.util.Map;

public class MemorySensitiveClassPathRepository extends AbstractClassPathRepository
{
    private final Map<String, SoftReference<JavaClass>> loadedClasses;
    
    public MemorySensitiveClassPathRepository(final ClassPath path) {
        super(path);
        this.loadedClasses = new HashMap<String, SoftReference<JavaClass>>();
    }
    
    @Override
    public void clear() {
        this.loadedClasses.clear();
    }
    
    @Override
    public JavaClass findClass(final String className) {
        final SoftReference<JavaClass> ref = this.loadedClasses.get(className);
        if (ref == null) {
            return null;
        }
        return ref.get();
    }
    
    @Override
    public void removeClass(final JavaClass clazz) {
        this.loadedClasses.remove(clazz.getClassName());
    }
    
    @Override
    public void storeClass(final JavaClass clazz) {
        this.loadedClasses.put(clazz.getClassName(), new SoftReference<JavaClass>(clazz));
        clazz.setRepository(this);
    }
}
